diff src/globals.h @ 673:513866ffe6af v7.0200

updated for version 7.0200
author vimboss
date Fri, 17 Feb 2006 21:53:23 +0000
parents 83a006f81bac
children e649c78407e6
line wrap: on
line diff
--- a/src/globals.h
+++ b/src/globals.h
@@ -507,11 +507,12 @@ EXTERN frame_T	*topframe;	/* top of the 
 
 #ifdef FEAT_WINDOWS
 /*
  * Tab pages are nothing more than alternative topframes.  "first_tabpage"
  * points to the first one in the list, "topframe" is the current one.
  */
-EXTERN tabpage_T *first_tabpage;
-EXTERN int	  redraw_tabpage INIT(= FALSE);	/* redraw tab pages line */
+EXTERN tabpage_T    *first_tabpage;
+EXTERN tabpage_T    *curtab;
+EXTERN int	    redraw_tabline INIT(= FALSE);  /* need to redraw tabline */
 #endif
 
 /*
@@ -507,11 +507,12 @@ EXTERN frame_T	*topframe;	/* top of the 
 #ifdef FEAT_WINDOWS
 /*
- * Tab pages are nothing more than alternative topframes.  "first_tabpage"
- * points to the first one in the list, "topframe" is the current one.
+ * Tab pages are alternative topframes.  "first_tabpage" points to the first
+ * one in the list, "curtab" is the current one.
  */